'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _varLoader = require('../util/var-loader');

var colorTransparent = (0, _varLoader.vLoader)('transparent');
var colorWhite = (0, _varLoader.vLoader)('#FFFFFF');
var colorBlack = (0, _varLoader.vLoader)('#000000');
var colorBrand11 = (0, _varLoader.vLoader)('#E4F0FD');
var colorBrand16 = (0, _varLoader.vLoader)('#3089DC');
var colorBrand19 = (0, _varLoader.vLoader)('#1170BC');
var colorLine11 = (0, _varLoader.vLoader)('#E6E7EB');
var colorLine12 = (0, _varLoader.vLoader)('#DCDEE3');
var colorLine13 = (0, _varLoader.vLoader)('#C4C6CF');
var colorLine14 = (0, _varLoader.vLoader)('#A0A2AD');
var colorFill11 = (0, _varLoader.vLoader)('#F7F8FA');
var colorFill12 = (0, _varLoader.vLoader)('#F2F3F7');
var colorFill13 = (0, _varLoader.vLoader)('#EBECF0');
var colorText11 = (0, _varLoader.vLoader)('#CCCCCC');
var colorText12 = (0, _varLoader.vLoader)('#999999');
var colorText13 = (0, _varLoader.vLoader)('#666666');
var colorText14 = (0, _varLoader.vLoader)('#333333');
var colorText15 = (0, _varLoader.vLoader)('#222222');
var colorWarning1 = (0, _varLoader.vLoader)('#FFF3E0');
var colorWarning2 = (0, _varLoader.vLoader)('#FFA033');
var colorWarning3 = (0, _varLoader.vLoader)('#ED6F00');
var colorError1 = (0, _varLoader.vLoader)('#FFEBEE');
var colorError2 = (0, _varLoader.vLoader)('#F44336');
var colorError3 = (0, _varLoader.vLoader)('#DB2F23');
var colorSuccess1 = (0, _varLoader.vLoader)('#F1F8E9');
var colorSuccess2 = (0, _varLoader.vLoader)('#1DC11D');
var colorSuccess3 = (0, _varLoader.vLoader)('#0DA80D');
var colorNotice1 = (0, _varLoader.vLoader)('#E3F2FD');
var colorNotice2 = (0, _varLoader.vLoader)('#2196F3');
var colorNotice3 = (0, _varLoader.vLoader)('#1681D9');
var colorHelp1 = (0, _varLoader.vLoader)('#FDF5FF');
var colorHelp2 = (0, _varLoader.vLoader)('#B921F3');
var colorHelp3 = (0, _varLoader.vLoader)('#A116D9');
var colorLink1 = (0, _varLoader.vLoader)('#FDF5FF');
var colorLink2 = (0, _varLoader.vLoader)('#2196F3');
var colorLink3 = (0, _varLoader.vLoader)('#A116D9');
var colorOther1 = (0, _varLoader.vLoader)('#FDF5FF');

/**
 * 颜色
 * @namespace component
 * @property module color
 * @property category style
 */

var varMap = {
  /**
   * 内置色
   * @namespace inset
   */

  /**
   * transparent
   * @property group color-inset
   * @property semantic 透明
   * @property export
   */
  'color-transparent': colorTransparent,
  /**
   * white
   * @property group color-inset
   * @property semantic 纯白
   * @property export
   */
  'color-white': colorWhite,
  /**
   * black
   * @property group color-inset
   * @property semantic 纯黑
   * @property export
   */
  'color-black': colorBlack,

  /**
   * 品牌色
   * @namespace brand
   */

  /**
   * 品牌主色
   * @namespace color-brand1
   * @property group brand
   */

  /**
   * brand1-1
   * @property group color-brand1
   * @property semantic 浅
   * @property export
   */
  'color-brand1-1': colorBrand11,
  /**
   * brand1-6
   * @property group color-brand1
   * @property semantic 常规
   * @property export
   */
  'color-brand1-6': colorBrand16,
  /**
   * brand1-9
   * @property group color-brand1
   * @property semantic 深
   * @property export
   */
  'color-brand1-9': colorBrand19,

  /**
   * 中立色
   * @namespace neutral
   */

  /**
   * 线条
   * @namespace color-line1
   * @property group neutral
   */

  /**
   * line1-1
   * @property group color-line1
   * @property semantic 浅
   * @property export
   */
  'color-line1-1': colorLine11,
  /**
   * line1-2
   * @property group color-line1
   * @property semantic 常规
   * @property export
   */
  'color-line1-2': colorLine12,
  /**
   * line1-3
   * @property group color-line1
   * @property semantic 深
   * @property export
   */
  'color-line1-3': colorLine13,
  /**
   * line1-4
   * @property group color-line1
   * @property semantic 重
   * @property export
   */
  'color-line1-4': colorLine14,

  /**
   * fill1-1
   * @property group color-fill1
   * @property semantic 浅
   * @property export
   */
  'color-fill1-1': colorFill11,
  /**
   * fill1-2
   * @property group color-fill1
   * @property semantic 常规
   * @property export
   */
  'color-fill1-2': colorFill12,
  /**
   * fill1-3
   * @property group color-fill1
   * @property semantic 深
   * @property export
   */
  'color-fill1-3': colorFill13,

  /**
   * text1-1
   * @property group color-text1
   * @property semantic 禁用/水印
   * @property export
   */
  'color-text1-1': colorText11,
  /**
   * text1-2
   * @property group color-text1
   * @property semantic 脚注
   * @property export
   */
  'color-text1-2': colorText12,
  /**
   * text1-3
   * @property group color-text1
   * @property semantic 正文
   * @property export
   */
  'color-text1-3': colorText13,
  /**
   * text1-4
   * @property group color-text1
   * @property semantic 标题
   * @property export
   */
  'color-text1-4': colorText14,
  /**
   * text1-5
   * @property group color-text1
   * @property semantic 重
   * @property export
   */
  'color-text1-5': colorText15,

  /**
   * 功能色
   * @namespace funtional
   */

  /**
   * 成功
   * @namespace color-success
   * @property group funtional
   */

  /**
   * success-1
   * @property group color-success
   * @property semantic 浅
   * @property export
   */
  'color-success-1': colorSuccess1,
  /**
   * success-2
   * @property group color-success
   * @property semantic 常规
   * @property export
   */
  'color-success-2': colorSuccess2,
  /**
   * success-3
   * @property group color-success
   * @property semantic 深
   * @property export
   */
  'color-success-3': colorSuccess3,

  /**
   * 提示
   * @namespace color-notice
   * @property group funtional
   */

  /**
   * notice-1
   * @property group color-notice
   * @property semantic 浅
   * @property export
   */
  'color-notice-1': colorNotice1,
  /**
   * notice-2
   * @property group color-notice
   * @property semantic 常规
   * @property export
   */
  'color-notice-2': colorNotice2,
  /**
   * notice-3
   * @property group color-notice
   * @property semantic 深
   * @property export
   */
  'color-notice-3': colorNotice3,

  /**
   * 警告
   * @namespace color-warning
   * @property group funtional
   */

  /**
   * warning-1
   * @property group color-warning
   * @property semantic 浅
   * @property export
   */
  'color-warning-1': colorWarning1,
  /**
   * warning-2
   * @property group color-warning
   * @property semantic 常规
   * @property export
   */
  'color-warning-2': colorWarning2,
  /**
   * warning-3
   * @property group color-warning
   * @property semantic 深
   * @property export
   */
  'color-warning-3': colorWarning3,

  /**
   * 错误
   * @namespace color-error
   * @property group funtional
   */

  /**
   * error-1
   * @property group color-error
   * @property semantic 浅
   * @property export
   */
  'color-error-1': colorError1,
  /**
   * error-2
   * @property group color-error
   * @property semantic 常规
   * @property export
   */
  'color-error-2': colorError2,
  /**
   * error-3
   * @property group color-error
   * @property semantic 深
   * @property export
   */
  'color-error-3': colorError3,

  /**
   * 帮助
   * @namespace color-help
   * @property group funtional
   */

  /**
   * help-1
   * @property group color-help
   * @property semantic 浅
   * @property export
   */
  'color-help-1': colorHelp1,
  /**
   * error-2
   * @property group color-error
   * @property semantic 常规
   * @property export
   */
  'color-help-2': colorHelp2,
  /**
   * error-3
   * @property group color-error
   * @property semantic 深
   * @property export
   */
  'color-help-3': colorHelp3,

  /**
   * 链接
   * @namespace color-link
   * @property group funtional
   */

  /**
   * link-1
   * @property group color-link
   * @property semantic 默认
   * @property export
   */
  'color-link-1': colorLink1,
  /**
   * link-2
   * @property group color-link
   * @property semantic 已访问
   * @property export
   */
  'color-link-2': colorLink2,
  /**
   * link-3
   * @property group color-link
   * @property semantic 激活
   * @property export
   */
  'color-link-3': colorLink3,

  /**
   * 其他
   * @namespace color-other
   * @property group funtional
   */

  /**
   * other-1
   * @property group color-other
   * @property semantic 默认
   * @property export
   */
  'color-other-1': colorOther1
};

exports.default = varMap;
module.exports = exports['default'];