'use strict';

import { vLoader } from '../util/var-loader';
import * as color from './color';

const shadow1 = vLoader('1px 1px 3px 0 rgba(0,0,0,0.12)');
const shadow2 = vLoader('2px 3px 4px 0 rgba(0,0,0,0.12)');
const shadow3 = vLoader('2px 3px 5px 0 rgba(0,0,0,0.12)');
const shadowDistanceSd1 = vLoader('1px');
const shadowDistanceSd2 = vLoader('2px');
const shadowDistanceSd3 = vLoader('3px');
const shadowBlurSd1 = vLoader('3px');
const shadowBlurSd2 = vLoader('4px');
const shadowBlurSd3 = vLoader('5px');
const shadowSpreadSd1 = vLoader(0);
const shadowSpreadSd2 = vLoader(0);
const shadowSpreadSd3 = vLoader(0);
const shadowColorSd1 = vLoader(color['color-black']);
const shadowColorSd2 = vLoader(color['color-black']);
const shadowColorSd3 = vLoader(color['color-black']);
const shadowOpacitySd1 = vLoader(0.12);
const shadowOpacitySd2 = vLoader(0.12);
const shadowOpacitySd3 = vLoader(0.12);

/**
 * 阴影
 * @namespace component
 * @property module shadow
 * @property category style
 */

const varMap = {
  /**
   * shadow-1
   * @property semantic 阴影1
   * @property export
   * @property calculate ['shadow-distance-sd1'] ['shadow-distance-sd1'] ['shadow-blur-sd1'] ['shadow-spread-sd1'] rgba(['shadow-color-sd1'], ['shadow-opacity-sd1'])
   */
  'shadow-1': shadow1,
  /**
   * shadow-2
   * @property semantic 阴影2
   * @property export
   * @property calculate ['shadow-distance-sd2'] ['shadow-distance-sd2'] ['shadow-blur-sd2'] ['shadow-spread-sd2'] rgba(['shadow-color-sd2'], ['shadow-opacity-sd2'])
   */
  'shadow-2': shadow2,
  /**
   * shadow-3
   * @property semantic 阴影3
   * @property export
   * @property calculate ['shadow-distance-sd3'] ['shadow-distance-sd3'] ['shadow-blur-sd3'] ['shadow-spread-sd3'] rgba(['shadow-color-sd3'], ['shadow-opacity-sd3'])
   */
  'shadow-3': shadow3,
  /**
   * shadow-distance-sd1
   * @property semantic 阴影1距离
   */
  'shadow-distance-sd1': shadowDistanceSd1,
  /**
   * shadow-distance-sd2
   * @property semantic 阴影2距离
   */
  'shadow-distance-sd2': shadowDistanceSd2,
  /**
   * shadow-distance-sd3
   * @property semantic 阴影3距离
   */
  'shadow-distance-sd3': shadowDistanceSd3,
  /**
   * shadow-opacity-sd1
   * @property semantic 阴影1透明度
   */
  'shadow-opacity-sd1': shadowOpacitySd1,
  /**
   * shadow-opacity-sd2
   * @property semantic 阴影2透明度
   */
  'shadow-opacity-sd2': shadowOpacitySd2,
  /**
   * shadow-opacity-sd3
   * @property semantic 阴影3透明度
   */
  'shadow-opacity-sd3': shadowOpacitySd3,
  /**
   * shadow-color-sd1
   * @property semantic 阴影1颜色
   */
  'shadow-color-sd1': shadowColorSd1,
  /**
   * shadow-color-sd2
   * @property semantic 阴影2颜色
   */
  'shadow-color-sd2': shadowColorSd2,
  /**
   * shadow-color-sd3
   * @property semantic 阴影3颜色
   */
  'shadow-color-sd3': shadowColorSd3,
  /**
   * shadow-blur-sd1
   * @property semantic 阴影1羽化值
   */
  'shadow-blur-sd1': shadowBlurSd1,
  /**
   * shadow-blur-sd2
   * @property semantic 阴影2羽化值
   */
  'shadow-blur-sd2': shadowBlurSd2,
  /**
   * shadow-blur-sd3
   * @property semantic 阴影3羽化值
   */
  'shadow-blur-sd3': shadowBlurSd3,
  /**
   * shadow-spread-sd1
   * @property semantic 阴影1扩散值
   */
  'shadow-spread-sd1': shadowSpreadSd1,
  /**
   * shadow-spread-sd2
   * @property semantic 阴影2扩散值
   */
  'shadow-spread-sd2': shadowSpreadSd2,
  /**
   * shadow-spread-sd3
   * @property semantic 阴影3扩散值
   */
  'shadow-spread-sd3': shadowSpreadSd3,
};

export default varMap;
